@@ -89,6 +89,10 @@ repos = OrderedDict({
         'cloudmesh-manual',
     ],
 
+    'mpi': cms + [
+        'cloudmesh-mpi'
+    ],
+
     'cloud': cloud,
 
     'javascript': cloud + [
@@ -327,7 +331,11 @@ repos = OrderedDict({
         [
             'book'
         ],
-
+    
+    'jobs': cms + [
+        'cloudmesh-job',
+    ],
+    
     'fa19-516': hostlist.expand_hostlist("fa19-516-[140-172,174]"),
 
     'fa19-523': hostlist.expand_hostlist("fa19-523-[180-196,198-212]"),
